@@ -1,8 +1,9 @@
 import inspect
 import itertools
+import time
 from typing import Callable, Union
-from .message import Message, PrivateMessage
 from .chat import DGGChat, EventType
+from .message import Message, PrivateMessage
 
 
 class DGGBot(DGGChat):
@@ -23,23 +24,31 @@ class DGGBot(DGGChat):
         self._owner = owner.lower() if owner else None
         self.prefix = prefix
         self._commands = {}
+        bot_config = self.config.get("bot", dict())
+        self._send_cooldown = bot_config.get("sendMsgCooldown", 0)
+        self._last_send_time = None
 
     def command(
         self,
         aliases: Union[list[str], tuple[str]] = tuple(),
         *args,
+        cooldown: Union[int, float] = None,
         whisper_only: bool = False,
         **kwargs,
     ):
         """
         Decorator to add commands to bot.
         :param aliases: aliases to call the function besides the function name.
+        :param cooldown: Cooldown (in seconds) between command uses.
         :param whisper_only: Command will only run when through whispers/private messages.
         :return:
         """
 
         def decorator(func: Callable):
             func._args = inspect.getfullargspec(func)
+            if cooldown is not None:
+                func._cooldown = cooldown
+                func._last_called = 0
             if whisper_only:
                 func = self.check(lambda msg: isinstance(msg, PrivateMessage))(func)
             for cmd_name in itertools.chain((func.__name__,), aliases):
@@ -52,12 +61,18 @@ class DGGBot(DGGChat):
         return decorator
 
     def is_command(self, msg: Message) -> bool:
-        return msg.data.startswith(self.prefix)
+        if isinstance(msg.data, str):
+            return msg.data.startswith(self.prefix)
 
     def on_command(self, msg: Message):
         cmd = msg.data.split(" ")[0][1:]
         if cmd in self._commands:
             func: callable = self._commands[cmd]
+            if hasattr(func, "_cooldown"):
+                ts = int(msg.timestamp.timestamp())
+                if (ts - func._last_called) < (func._cooldown):
+                    return
+                func._last_called = ts
             if hasattr(func, "_perms"):
                 perms = func._perms
                 if any(not perm(msg) for perm in perms):
@@ -87,5 +102,12 @@ class DGGBot(DGGChat):
         return self.check(lambda msg: msg.nick.lower() == self._owner)
 
     def _post_message(self, msg: Message):
-        if self.is_command(msg) and msg.type in (EventType.MESSAGE, EventType.PRIVMSG):
+        if msg.type in (EventType.MESSAGE, EventType.PRIVMSG) and self.is_command(msg):
             self.on_command(msg)
+
+    def send(self, msg: str):
+        if self._last_send_time is not None and self._send_cooldown:
+            if (time.time() - self._last_send_time) < self._send_cooldown:
+                return
+        super().send(msg)
+        self._last_send_time = time.time()
